## agentsitter.ai

`A baby sitter for your agents.`

Agent Sitter is a layer 7 proxy [sitter] and an approval engine [app]. 

The `sitter` intercepts and monitors your AI agent's http / https traffic and detects risky / suspicious activity. When the `sitter` detects a risky action, it redirects your agent to a waiting page and submits the approval to a human via the `app`.

To install and configure agent sitter use the `sittr` cli.

Any AI agent with access to the web can be babysat by agentsitter. This repo focuses on [browser-use](https://github.com/browser-use/browser-use/) agents but more examples will be added.

## System Requirements

Linux / OSX - for windows support see / vote for [this issue](https://github.com/phact/agent-sitter/issues)


## Getting started

### Installation

    uvx 

#### Local

    uvx --with browser_use python main.py

